	SUBROUTINE SO_IFSP  ( rimnem, cimnem, iret )
C************************************************************************
C* SO_IFSP								*
C*									*
C* This subroutine sets the pointers within COMMON / RINTFP / and	*
C* COMMON / CINTFP /.							*
C*									*
C* SO_IFSP  ( IRET )							*
C*									*
C* Input parameters:                                                    *
C*      MXNPTS          INTEGER         Max number of data points to    *
C*                                      decode                          *
C*      NRIMN           INTEGER         Number of real interface        *
C*                                      mnemonics                       *
C*      RIMNEM (*)      REAL            Real interface mnemonics array  *
C*      CIMNEM (*)      CHAR*           Char interface mnemonics array  *
C*                                                                      *
C* Output parameters:                                                   *
C*	IRET		INTEGER		Return code 			*
C*					  0 = normal return 		*
C*					 -1 = One or more pointers	*
C*					      could not be set 		*
C*									*
C**									*
C* Log:									*
C* D. Kidwell/NCEP	10/97	Adapted from AF_IFSP			*
C* R. Hollern/NCEP	 3/98   Changes based on LS_IFSP                *
C* R. Hollern/NCEP	 1/99   Initialized interface mnemonics and     *
C*                              added interface mnemonic arrays to      *
C*                              calling sequence                        *
C* R. Hollern/NCEP	10/00   Added date/time interface mnemonics     *
C* J. Ator/NCEP		01/02	CMCM -> SWCM, SUWS -> TIWM		*
C* C. Caruso Magee/NCEP 01/06   Replace iryear with irydgt.             *
C************************************************************************
	INCLUDE		'socmn.cmn'
C*
        CHARACTER       rimnem ( NRIMN )*8, cimnem ( NCIMN )*8
C*
	LOGICAL		allok
        INTEGER         iploc( NRSLMN ),   jploc( NCIMN )
        CHARACTER       rifmn ( NRIMN )*8, cifmn ( NCIMN )*8
C*
C*	Establish array equivalence to COMMON / RINTFP /
C*
	EQUIVALENCE	( iploc (1), irydgt ), ( jploc (1), icsana )
C*
C*      Real interface mnemonics.
C*
	DATA	( rifmn (i), i = 1, NRSLMN ) /
     +		'YDGT'  , 'MNTH'  , 'DAYS'  , 'HOUR'    ,  'MINU'  ,
     +		'TIWM'  , 'SWCM'  , 'SAID'  , 'GENCTR'  ,  'SACO'  / 
C*
	DATA	( rifmn (i), i = 11, NRIMN ) /
     +		'NPTS'  , 'SLAT'  , 'SLON'  , 'PRES'    ,  'TMDB'  , 
     +		'WDIR'  , 'WDSP'  , MXM1T * ' '                    /
C*
C*      Character interface mnemonics.
C*
        DATA    ( cifmn (i), i = 1, NCIMN )
     +		/ 'SANA'  /
C-----------------------------------------------------------------------
	iret = 0
C
        DO i = 1, NRIMN
            rimnem ( i ) = rifmn ( i )
        END DO
C
        DO i = 1, NCIMN
            cimnem ( i ) = cifmn ( i )
        END DO
C
C*	The logical variable "allok" is initially set to .true. but will
C*	be reset to .false. if any of the pointers cannot be set.
C
	allok = .true.
C
C*	Set the pointers for the single-level interface mnemonics.
C
	DO i = 1, NRSLMN
	    CALL DC_IFFP ( rimnem ( i ), rimnem, NRIMN, allok, 
     +                     iploc ( i ), ier )
	END DO
C
C*	Set the pointers for the multi-level interface mnemonics.
C
	CALL DC_IFFP  ( 'NPTS', rimnem, NRIMN, allok, irnpts, ier )
	CALL DC_IFFP  ( 'SLAT', rimnem, NRIMN, allok, irslat, ier )
	CALL DC_IFMP  ( 6, MXNPTS, irslat, ier )
	CALL DC_IFFP  ( 'SLON', rimnem, NRIMN, allok, irslon, ier )
	CALL DC_IFMP  ( 6, MXNPTS, irslon, ier )
	CALL DC_IFFP  ( 'PRES', rimnem, NRIMN, allok, irpres, ier )
	CALL DC_IFMP  ( 6, MXNPTS, irpres, ier )
	CALL DC_IFFP  ( 'TMDB', rimnem, NRIMN, allok, irtmdb, ier )
	CALL DC_IFMP  ( 6, MXNPTS, irtmdb, ier )
	CALL DC_IFFP  ( 'WDIR', rimnem, NRIMN, allok, irwdir, ier )
	CALL DC_IFMP  ( 6, MXNPTS, irwdir, ier )
	CALL DC_IFFP  ( 'WDSP', rimnem, NRIMN, allok, irwdsp, ier )
	CALL DC_IFMP  ( 6, MXNPTS, irwdsp, ier )
C
	DO i = 1, NCIMN 
	    CALL DC_IFFP ( cimnem ( i ), cimnem, NCIMN, allok, 
     +                     jploc ( i ), ier )
	END DO
C
C*	Set the pointers for the data points.
C
        CALL DC_IFFP  ( 'NPTS', rimnem, NRIMN, allok, irnpts, ier )
C
C*	Were all of the pointers properly set?
C
	IF  ( .not. allok ) THEN
	    iret = -1
	END IF
C*
	RETURN
	END
