       SUBROUTINE  SO_PPTT ( bulltn, kpos, iret ) 
C************************************************************************
C*                                                                      *
C* SO_PPTT                                                              *
C*                                                                      *
C* This routine decodes the (Pc Pc Tc Tc Ta) groups in section 2. Pc Pc *
C* is the pressure level, in tens of hectopaschals, derived from a      *
C* conversion of cloud temperature and related to the level where cloud *
C* displacement was observed.  Tc Tc is the temperature of the cloud    *
C* top, in whole degrees Celsius, at pressure estimated from infrared   *
C* observations of clouds.  Ta is the approximate tenths value and sign *
C* of the temperature.                                                  *
C*                                                                      *
C*                                                                      *
C* SO_PPTT ( BULLTN, KPOS, IRET )                                       *
C*                                                                      *
C* Input parameters:                                                    *
C*      BULLTN          CHAR*           Bulletin array                  *
C*      IOBSPT          INTEGER         Index value for pointer arrays  *
C*					                                *
C* Input and output parameters:                                         *
C*      KPOS            INTEGER         On input, points to start of    *
C*                                      PPTTT group; on ouput, points   *
C*                                      to start of the following       *
C*                                      ddfff group                     *
C*                                                                      *
C* Output parameters:                                                   *
C*      RIVALS(IRPRES)  REAL            Pressure in hectopaschals at    *
C*                                      data point                      *
C*      RIVALS(IRTMDP)  REAL            Temperature in Kelvin  at data  *
C*                                      point                           *
C*	IRET	        INTEGER         Return code                     *
C*                                       0 = normal return              *
C*                                       1 = problems                   *
C*                                                                      *
C**                                                                     *
C* Log:                                                                 *
C* R. Hollern/NCEP      10/96                                           *
C* R. Hollern/NCEP      11/96  Added call to PR_TMCK                    *
C* R. Hollern/NCEP      12/96  Replaced ST_C2R with ST_INTG             *
C* R. Hollern/NCEP       2/97  Added check for P(c)P(c) set to 00       *
C* R. Hollern/NCEP       3/98  Changed interface and cleaned up code    *
C************************************************************************
        INCLUDE    'socmn.cmn'
C*
        CHARACTER*(*)   bulltn
C*
        CHARACTER   fld2*2,   fld1*1
C------------------------------------------------------------------------
        iret = 0
        ipt = kpos
        kpos = kpos + 6
C
C*      Get estimated pressure in of hectopaschals.
C
        fld2 = bulltn ( ipt:ipt+1 )
        ipt = ipt + 2
        CALL ST_INTG ( fld2, ival, ier )
        IF ( ier .eq. 0 ) THEN
C
            IF ( ival .eq. 0 ) THEN
                ival = 100
            END IF
C
            rval = FLOAT ( ival )
            rivals ( irpres ( iobspt ) ) = 10. * rval
          ELSE
            RETURN
        END IF
C
C*      Get temperature of cloud top, in whole degrees Celsius.
C
        fld2 = bulltn ( ipt:ipt+1 )
        ipt = ipt + 2
        CALL ST_INTG ( fld2, ival, ier )
        IF ( ier .eq. 0 ) THEN
            rval = FLOAT ( ival )
            xtemp = rval
          ELSE
            RETURN
        END IF
C
C*      Get approximate tenths value and sign of temperature.
C
        fld1 = bulltn ( ipt:ipt )
        CALL ST_INTG ( fld1, ival, ier )
C
        IF ( ier .eq. 0 ) THEN
            irem = MOD(ival,2)
C
            IF ( irem .eq. 0 ) THEN
                xsgn = 1.0
              ELSE
                xsgn = -1.0
            END IF
C
            xval = FLOAT ( ival )
            xtemp = xtemp + ( .1*xval )
C
C*          Convert temperature from Celsius to Kelvin.
C
            x = xsgn * xtemp
            rivals ( irtmdb ( iobspt ) ) = PR_TMCK ( x )
          ELSE
            RETURN
        END IF
C*
	RETURN 
	END
