       SUBROUTINE  SO_SEC2 ( lenb, bulltn, kpos, iret )
C************************************************************************
C*                                                                      *
C* SO_SEC2                                                              *
C*                                                                      *
C* This subroutine calls the routines to decode the groups in section 2 *
C* of the WMO FM 88 SATOB bulletin.  The section contains (1) cloud or  *
C* water-vapour temperature data and (2) wind data computed from cloud  *
C* movement or water-vapour motion at specified pressure levels.  The   *
C* number of data points varies from bulletin to bulletin.              *
C*                                                                      *
C* SO_SEC2 ( LENB, BULLTN, KPOS, IRET )                                 *
C*                                                                      *
C* Input parameters:                                                    *
C*      LENB            INTEGER         Bulletin length in bytes        *
C*      BULLTN          CHAR*           Bulletin array                  *
C*      KPOS            INTEGER         Pointer set to start of the     *
C*                                      first BBBnn group in bulltn     *
C*      IOBSPT          INTEGER         Index value for pointer arrays  *
C*					                                *
C* Output parameters:                                                   *
C*      RIVALS(IRSLAT)  REAL            Latitude of data point          *
C*      RIVALS(IRSLON)  REAL            Longitude of data point         *
C*      RIVALS(IRNPTS)  REAL            Number of data points           *
C*	IRET	        INTEGER         Return code                     *
C*				   	 0 = normal return              *
C*                                       1 = reject bulletin            *
C*                                                                      *
C**                                                                     *
C* Log:                                                                 *
C* R. Hollern/NCEP      10/96                                           *
C* R. Hollern/NCEP       3/98  Changed interface and cleaned up code    *
C************************************************************************
        INCLUDE    'socmn.cmn'
C
        CHARACTER*(*)    bulltn
C
        REAL   xlatln(2,2)
C
        LOGICAL  again
C------------------------------------------------------------------------
        iret = 0
        ipt = kpos
        iobspt = 0
        numpts = 0
        again = .true.
C
        DO WHILE ( again )
C
C*          Get the latitude/longitude cordinates of the B1 B2 B3
C*          square and the number of observational data points in square
C
            CALL SO_BBBN ( bulltn, kpos, ipole, clat, clong, nnpts,
     +                     ib1, kret )
C
            IF ( kret .ne. 0 ) THEN
                iret = 1
                RETURN
            END IF 
C
            numpts = iobspt + nnpts
C
C*          Do not exceed 900 points, since  BUFR message limited to
C*          10000 bytes.
C
            IF ( numpts .ge. 900 ) THEN
                nnpts = nnpts - ( numpts - 900 )
                again = .false.
            END IF
C
            ipts = nnpts / 2
            irem = MOD(nnpts,2)
            IF ( irem .ne. 0 ) THEN
                ipts = ipts + 1
            END IF
C
            IF ( ipole .ne. 0 ) THEN
C
C*              Skip polar data groups, since geostationary satellite
C*              should not send these groups.        
C
                kpos = kpos + ( 30*ipts )
C
C*              Skip following DO loop.
C
                ipts = 0
            END IF
C
            DO i = 1,ipts
C
C
C
C*              Decode the (ULa ULo ULa ULo /) group.
C
                CALL SO_UUUU ( bulltn, ib1, clat, clong, kpos, xlatln,
     +                         kret )
C
                DO j = 1,2
C
                    IF ( xlatln(j,1) .ne. -999.0 ) THEN
C
C*                      Check if missing groups at end of bulletin.
C
                        IF ( (kpos + 8) .gt. lenb ) THEN
                            rivals ( irnpts ) = iobspt
                            RETURN
                        END IF
C
                        iobspt = iobspt + 1
C
C*                      Get lat/long location of data point.
C
                        rivals ( irslat ( iobspt ) ) = xlatln (j,1 )
                        rivals ( irslon ( iobspt ) ) = xlatln (j,2 )
C
                        CALL SO_PPTT ( bulltn, kpos, kret )
C
C*                      Decode the ddfff group.
C
                        CALL SO_DDFF ( bulltn, kpos, kret )
                      ELSE
C
C*                      Skip over the groups set to slashes.
C
                        kpos = kpos + 12
                    END IF
                END DO
C
            END DO
C
            IF ( (kpos + 10) .gt. lenb ) THEN
                again = .false.
            END IF
        END DO
C
C*      Number of data points.
C
        IF ( iobspt  .gt. 0 ) THEN
            rivals ( irnpts ) = iobspt
        END IF 
C*
	RETURN
	END
