       SUBROUTINE  SO_UUPP ( bulltn, kpos, ib1, clat, clong, iret ) 
C************************************************************************
C*                                                                      *
C* SO_UUPP                                                              *
C*                                                                      *
C* This routine decodes the (ULa ULo Pe Pe /) groups in section 3. The  *
C* ULa is the units digit in the reported latitude and ULo is the units *
C* digit in the reported longitude.  The latitude and longitude position*
C* of the point in the B1 B2 B3 square is determined from the quantities*
C* ULa, ULo, clat, and clong.  Pe Pe is the estimated pressure, in tens *
C* of hectopascals, at the given point.                                 *
C*                                                                      *
C* SO_UUPP ( BULLTN, KPOS, IB1, CLAT, CLONG, IRET )                     *
C*                                                                      *
C* Input parameters:                                                    *
C*      BULLTN          CHAR*           Bulletin array                  *
C*      IB1             INTEGER         The octant of the globe         *
C*      CLAT            REAL            The latitude of the reference   *
C*                                      point of the BBB square         *
C*      CLONG           REAL            The longitude of the reference  *
C*                                      point of the BBB square         *
C*      IOBSPT          INTEGER         Index value for pointer arrays  *
C*
C* Input and output parameters:                                         *
C*      KPOS            INTEGER         On input, points to start of    *
C*                                      uupp/ group; on ouput, points   *
C*                                      to start of the following       *
C*                                      ddfff group                     *
C*					                                *
C* Output parameters:                                                   *
C*      RIVALS(IRSLAT)  REAL            Latitude of data point          *
C*      RIVALS(IRSLON)  REAL            Longitude of data point         *
C*      RIVALS(IRPRES)  REAL            Estimated pressure in           *
C*                                      hectopaschals at data point     *
C*	IRET	        INTEGER         Return code                     *
C*				   	 0 = normal return              *
C*                                       1 = reject bulletin            *
C* Log:                                                                 *
C* R. Hollern/NCEP      10/96                                           *
C* R. Hollern/NCEP      12/96  Replaced ST_C2R with ST_INTG             *
C* R. Hollern/NCEP       2/97  Added check for P(e)P(e) set to 00       *
C* R. Hollern/NCEP       3/98  Changed interface and cleaned up code    *
C************************************************************************
        INCLUDE    'socmn.cmn'
C*
        CHARACTER*(*)   bulltn
C*
        CHARACTER       fld2*2,   fld1*1
C------------------------------------------------------------------------
        iret = 0
        ipt = kpos
        kpos = kpos + 6
C
C*      Determine the sign of the lat/long position.  The Geo
C*      stationary satellite does not report winds at the poles.
C
        IF ( ib1 .eq. 0 .or. ib1 .eq. 1 ) THEN
            sgnla = 1.0
            sgnlo = -1.0
          ELSE IF ( ib1 .eq. 2 .or. ib1 .eq. 3 ) THEN
            sgnla = 1.0
            sgnlo = 1.0
          ELSE IF ( ib1 .eq. 5 .or. ib1 .eq. 6 ) THEN
            sgnla = -1.0
            sgnlo = -1.0
          ELSE IF ( ib1 .eq. 7 .or. ib1 .eq. 8 ) THEN
            sgnla = -1.0
            sgnlo = 1.0
          ELSE
            iret = 1
            RETURN
        END IF
C
        IF ( clong .eq. 180. ) THEN
            sgnlo = 1.0
        END IF
C
C*      Get the units digit in the reported latitude.
C
        fld1 = bulltn ( ipt:ipt )
        ipt = ipt + 1
        CALL ST_INTG ( fld1, ival, ier )
        IF ( ier .eq. 0 ) THEN
            rval = FLOAT ( ival )
            rval = sgnla * rval
            rivals ( irslat ( iobspt ) ) = clat + rval
          ELSE
            iret = 1
            RETURN
        END IF
C
C*      Get the units digit in the reported longitude.
C
        fld1 = bulltn ( ipt:ipt )
        ipt = ipt + 1
        CALL ST_INTG ( fld1, ival, ier )
        IF ( ier .eq. 0 ) THEN
            rval = FLOAT ( ival )
            rval = sgnlo * rval
            rivals ( irslon ( iobspt ) ) = clong + rval
          ELSE
            iret = 1
            RETURN
        END IF
C
C*      Estimated pressure in hectopaschals.
C
        fld2 = bulltn ( ipt:ipt+1 )
        CALL ST_INTG ( fld2, ival, ier )
        IF ( ier .eq. 0 ) THEN
            IF ( ival .eq. 0 ) THEN
                ival = 100
            END IF
            rval = FLOAT ( ival )
            rivals ( irpres ( iobspt ) ) = 10. * rval
          ELSE
            iret = 1
            RETURN
        END IF
C*
	RETURN
	END
